---
title: "A 890 fj bit UWB Transmitter for SOC Integration in High Bit-Rate Transcutaneous Bio-Implants"
date: 2013-05-19T15:26:46+01:00
draft: false
toc: true
type: posts
math: true
tags:
  - publication
  - wireless
  - CMOS
  - biomedical
  - telemetry
---


Lieuwe B. Leene, Song Luan, Timothy G. Constandinou

Department of Electrical and Electronic Engineering, Imperial College London, SW7 2BT, UK

Centre for Bio-Inspired Technology, Institute of Biomedical Engineering, Imperial College London, SW7 2AZ, UK

# 1 Abstract

The paper presents a novel ultra low power UWB transmitter system for near field communication in transcutaneous bio-telemetries. The system utilizes an all-digital architecture based on minimising the energy dissipated per bit transmitted by efficiently encoding a packet of pulses with multiple bits and utilizing oscillator referenced delays. This is achieved by introducing a novel bi-phasic 1.65 pJ per pulse UWB pulse generator together with a 72 μW DCO that provide a transmission bandwidth of 77.5 Mb/s with an energy efficiency of 890 fJ per bit from a 1.2 V supply. The circuit core occupies a compact silicon footprint of 0.026 mm² in a 0.18 μm CMOS technology.

# 2 Introduction

Since Pulsed Ultra Wide Band (UWB) technology has become available for unlicensed communication, a broad spectrum of ideas have been presented over the past decade with regard to UWB pulse modulation, generation and detection techniques[^1]. Recent literature has primarily demonstrated the potential all-digital UWB transmitters have in achieving ultra low power budgets by operating with aggressive duty cycles while maintaining substantial data rates. These developments are of considerable interest to biomedical applications, for example in neural interfaces estimates indicate that state-of-the-art systems already require data rates up to 40Mb/s without compression and a power budget of several  mili-watt[^2]. Moreover, based on the recent projection regarding the steady exponential growth in number of neurons recorded[^3], we expect a considerable demand for a ultra low power wireless link that is capable of transmitting 80 Mb/s and is viable for integration on chip with the neural sensory devices in the coming years.

The UWB transmitter presented here is based on developing a transcutaneous biotelemetry system where the transmitter is coupled to a receiver trough a near field communication channel across the skin boundary. The adoption of near field transmission for power and data is nearly ubiquitous in biotelemetry systems because it alleviates the challenge of coping with the lossy radiation environment of the human body and power restrictions due to thermal dissipation constraints. Moreover, near field communication should allow high SNR values with respect to interfering UWB devices such that a simple energy detection based receiver can fully detect the individual transmitted UWB pulses.

This work presents an UWB transmitter architecture for asynchronous communication that achieves ultra low power consumption by minimising the energy dissipated per bit transmitted (EPB). This is achieved through circuit level optimizations in addition to encoding a packet of pulses with multiple bits. Furthermore scalable PPM modulation is achieved with significant improvements in both resource requirements and phase integrity over conventional techniques that either use a tuneable delay element or multiple delay lines[^4].

This paper is organized as follows. Section 3 presents a discussion on the operation of the proposed architecture. Section 4 presents the transistor level implementations of a Digitally Calibrated Oscillator (DCO) and an novel UWB pulse shaper. Section 7 completes the design aspects of the transmitter by presenting the employed UWB antenna. Sections 8 & 13 demonstrate the performance of the proposed system and conclude upon this paper's findings.

# 3 UWB Transmitter System Concept

The system architecture of the UWB transmitter is shown in Fig. 1. This is based on using a DCO as a reference for the encoded delays intermediate to the pulse positions. This approach allows accurate definition of all relative pulse positions by calibrating a single element thereby reducing the system's resource requirement while maintaining scalability. The bi-phasic pulse generator extends this flexibility by allowing pulses to be modulated in terms of position and phase simultaneously.

{{< figure src="/images/iscas2012/s1.png" title="Figure 1: System level architecture of the UWB Transmitter capable of M-arry PPM and BPSK modulation" width="500" >}}

The PPM modulation mechanism relies on the removal or 'swallowing' of extraneous clock pulses generated by the DCO, hence introducing inter-pulse delays quantized by the DCO's period. This is achieved by disconnecting the power supply from the inter-stage buffer driving the pulse generator for specific intervals. These intervals are specified by a synchronized D flip-flop fed by a shift register with decisions to swallow or transmit the incoming pulse. Exact duty cycles are achieved by enabling the DCO on the rising edge of the input for a burst of clock cycles and disabling the DCO when the shift register detects the end of the pulse package.

A high speed all-digital frequency locked loop is used on system start up to calibrate the DCO to a fixed oscillation frequency. Calibration is an important consideration as DCO frequency off-sets for this topology results in increasingly larger temporal off-sets for increasingly longer pulse packages and amounts to significant phase noise at the receiver.

In order to maximize the efficiency of the transmitter, this system essentially cascades two delay-hopped time-reference (DHTR) pulse pairs where the second pulse is the reference pulse for the third pulse [^5]. The phase of each pulse is given by a 3-bit word, D<sub>2<sub> - D<sub>0<sub>. The implemented design allows the second pulse to be delayed to 8 different positions. The third pulse can then be delayed to 4 different positions with reference to the second pulse including a null position where the pulse is omitted. Note that when the third pulse is omitted standard DHTR modulation is achieved and the bit D0 is ignored. As a result each pulse package encodes 7.75 effective number of bits (ENOBs) with an average of 2.75 pulses per package for a equiprobable code book. The transmitted package may be represented analytically as

$$ s(t)= a_{i} w(t) + b_{i} w(t - A_i \cdot T_{DCO}) + c_i w( t - (A_i + B_i) \cdot T_{DCO} ) $$

where i is the package index, w(t) is the UWB pulse shape, and T<sub>DCO<sub> is the unit delay introduced by the DCO's period. a<sub>i<sub>, b<sub>i<sub>, c<sub>i<sub> in { +1, -1 } are the respective first, second, and third pulse phases. A<sub>i<sub> & B<sub>i<sub> are the respective delays of the first and second pulse pairs. Fig. 2 exemplifies two pulse packets with reference to the DCO clock whose encoding is given by; A<sub>1<sub>, B<sub>1<sub>, D(2-0)<sub>1<sub> = [010, 10, 010] and A<sub>2<sub>, B<sub>2<sub>, D(2-0)<sub>2 = [001, 01, 110].

{{< figure src="/images/iscas2012/ex.png" title="Figure 2: Waveforms illustrating two different DHTR modulated pulse packages. a) DCO reference, b) package index 1 [010, 10, 010], c) package index 2 [001, 01, 110]$. " width="500" >}}

# 4 Circuit Implementation

The circuit has been implemented in a commercially available 0.18 μm CMOS technology provided by AMS/IBM (C18A4/7sf) and has been designed to operate from a 1.2 V supply. This section details the circuit level design and implementation.

## 5 Digitally Calibrated Oscillator

The DCO employed by the UWB transmitter is an 8-bit calibrated 5-stage ring oscillator as shown in Fig. 3. The five most significant bits of the calibration state C<sub>7<sub> to C<sub>3<sub> adjust the main capacitive load by shorting a select set of capacitors from a binary weighted array to ground and leaving others floating. The lower 3 bits C<sub>2<sub> to C<sub>0<sub> fine tune the oscillation frequency by adjusting the NMOS side driving capability of an the inverter stage achieving a resolution in the order of tens of pico-seconds by making fractional changes in aspect ratio for different matched transistors. Since the transistor 'on' resistance is inversely proportional to the tuned driving capability of the inverter, a 3-input look-up-table-based remapping is introduced. This improves the performance of the fine calibration bits by linearizing the tuneable delay with respect to the control bits. Note that the main delay elements are primarily dependent on the NMOS devices and the parasitic capacitance which by reducing the dependence on PMOS devices improves the sensitivity to process variation.

{{< figure src="/images/iscas2012/s2.png" title="Figure 3: Circuit schematic of the 5-stage digitally calibrated Ring oscillator" width="500" >}}

## 6 UWB Pulse Shaper

The pulse shaper presented here has been partly adopted from previous work that used integrated LC components to filter out the unwanted spectrum to meet the FCC mask requirements[^6]. An integrated inductor is differentially pulsed with current over 180 ps which perturbs the LC resonator to start oscillating with the induced energy. This resonating energy is leaked towards the resistive load of the antenna over a longer time frame of 1ns. There is an explicit capacitive impedance mismatch at the bond-pad such that most of the energy induced by the driving transistors is fed into the inductor.

The circuit consists of a two part design, including digital and RF sections. The Digital pre-shaper is shown in Fig. 4. This uses a popular glitch generator to generate 180ps long Gaussian like pulses, which are demultiplexed to two inverter chains to boost the driving capability of the output. It is important to note that these chains have a different output polarity but both output the buffered pulse together with a delayed and inverted pulse. The driving transistors in Fig. 5 source the inductor with pulsed current proportional to the glitch duration. The purpose of the delayed pulse is to cancel the DC component generated by the transient impulse response of the lossy LC resonator, by injecting an equal but complementary pulse at the opposite port of the inductor. By driving either the end connected to the load, or the C<sub>res<sub> end of the inductor first, the polarity of the UWB pulse is well controlled.

The circuit shown in Fig. 4 also illustrates how a shift register can interface the UWB transmitter with a parallel input data stream. In the RF section (Fig. 5), it is interesting to note that since the transistor pairs M1, M4, M2, and M3 are matched in terms of driving capability this particular topology is immune to variations in pulse length. This would easily distort the output spectrum of aggressive UWB pulse generators that use multiple glitch generators to shape the pulse. The integrated 4 nH inductor is a single layer 6-turn 8-sided spiral with poly-silicon ground plane and dimensions 4 μm, 2.8 μm, 66 μm corresponding to the trace width, trace spacing, and outer radius respectively.

{{< figure src="/images/iscas2012/s3.png" title="Figure 4: Circuit Schematic of the digital pre-shaping" width="500" >}}

{{< figure src="/images/iscas2012/s4.png" title="Figure 5: Circuit schematic of the RF section with L = 4nH; C<sub>res<sub> = 200fF; - Note that the relative temporal delays of the driving signals are not to scale." width="500" >}}

# 7 Miniaturized UWB Antenna

An omni-directional UWB antenna that radiates in the plane of the skin boundary is used for near field coupling instead of an RF coil to reduce the potential interference from echos and other UWB sources. The antenna here is based on a generic elliptic co-planar mono-pole geometry which has been shown to have good non-dispersive radiation characteristics over the entire bandwidth[^7]. To assure that the radiated pulse meets the FCC requirements in the sub 2 GHz band, the antenna is required to reject this band by at least 20 dB with respect to the insertion loss in the 3.1 GHz - 10.6 GHz band.

{{< figure src="/images/iscas2012/gg.png" title="Figure 6: Illustration of the antenna geometry and a high contrast photograph of a prototype next to a British pound with dielectric cover removed." width="500" >}}

The antenna geometry is shown in Fig. 6, with the various antenna dimensions designed as follows; R = 5mm, R<sub>G<sub> = 400 μm, R<sub>T<sub> = 800 μm, G = 290 μm, W = 440 μm, C = 260 μm, t<sub>d<sub> = 635 μm, t<sub>m<sub> = 35 μm.

The antenna uses an asymmetric extended ground plane to damp the first strong resonance that is usually centred around 3-4GHz and can introduce significant pulse distortion. To improve the viability of the antenna for an implanted system a high dielectric laminate with copper metallization, RO1030, was used on both sides of the metallization to scale down the dimensions to allow an off-chip imprint below 2 cm².

# 8 Results

The design was simulated in Cadence IC 5.141 ISR with foundry-supplied PSP models. This section details the DCO, pulse generator, antenna and system performance.

## 9 Digitally Calibrated Oscillator

Monte Carlo simulation revealed the proposed DCO has a standard deviation in oscillation frequency of 44.9 MHz. The calibration mechanism allows the DCO to sweep through from 750 MHz to 390 MHz with a resolution of approximately 4.5 MHz as shown in Fig. 7. The DCO consumes an average of 72 μW during continuous operation at 500MHz.

{{< figure src="/images/iscas2012/swp.png" title="Figure 7: Transient simulation of the DCO sweeping through all calibration states" width="500" >}}

## 10 Pulse Generator

The transient simulation of the UWB pulse generator is illustrated in Fig. 8. This demonstrated a power dissipation of 1.65 pJ per pulse with a 344 mVpp Amplitude. Spectral analysis further shows a peak power spectral density of -50.6 dBm/MHz and FCC mask compliance over the 3.1 GHz - 10 GHz band.

{{< figure src="/images/iscas2012/tr.png" title="Figure 8a: bi-phasic UWB temporal response." width="500" >}}

{{< figure src="/images/iscas2012/dfs.png" title="Figure 8b: Simulated PSD of the designed UWB pulse & the indoor UWB FCC mask as annotated." width="500" >}}

## 11 UWB antenna

{{< figure src="/images/iscas2012/a1.png" title="Figure 9: Simulated reflection co-efficient S11 for the UWB antenna radiating in free space." width="500" >}}

Preliminary EM simulations were carried out using CST MICROWAVE STUDIO package with a 50 ohm port impedance. Fig. 9 shows the UWB antenna achieves a -10 dB reflection over the 3.66 GHz to 7 GHz band without significant phase distortion.

## 12 System Performance

The complete system level simulation is shown in Fig. 10. This demonstrates the transmitter operating with a package frequency rate (PRF) of 20 MHz transmitting a 155 Mb/s bit stream of pseudo random data while consuming less than 40 pJ under 300 ns. For the target 10MHz PRF, the system consumes an average of 68.9 μW corresponding to a 890 fJ of energy dissipated per bit transmitted. The custom digital layout is shown in Fig. 11. This measures 135 μm by 60 μm excluding the 132 μm by 132 μm integrated inductor, giving a total core area of 0.026 mm².

{{< figure src="/images/iscas2012/ps.png" title="Figure 10: Simulation result illustrating the voltage waveforms generated by the different components with a 20 MHz PRF and a random input data stream." width="500" >}}

{{< figure src="/images/iscas2012/tx.png" title="Figure 11: Core Layout of the UWB transmitter with each block annotated as; a) UWB Pulse shaper b) Pulse Swallowing c) Serial Interface d) DCO." width="500" >}}

# 13 Conclusion

An all-digital UWB transmitter architecture has been presented for biomedical SOC integration that seeks to improve system efficiency by achieving asynchronous ultra low power operation for arbitrary bit rates. A DCO based modulation scheme is introduced that significantly reduces the on-chip resource requirements for PPM modulation and allowed efficient 8-bit encoding onto 3 UWB pulses. The novel low power bi-phasic UWB pulse generator further allows this system to achieve 890 fJ EPB on a 0.18 μm CMOS process to make integration with state of the art neural interfaces viable. The overall system achieves very aggressive performance in terms of power consumption for 10MHz PRF as illustrated in table 1. Future work will focus on tuning the UWB antenna to match the tissue impedance and characterizing the near field communication channel.

Table 1: Performance overview of recent UWB transmitters
|Reference | [^8] | [^9] | [^10] | [^11] | [^12] | This Work |
|----|----|----|----|----|----|----|
|Tech. (nm) | 65 | 130 | 65 | 65 | 65 | 180 |
|Modulation | DHTR | BPSK | PPM | OOK | BPSK | DHTR |
|Power (W) | 660n | 3.3m | 820u | 217u | 4.36m | 68.9u |
|PRF (Hz) | 0.6M | 100M | 50M | 24M | 15.6M |  10M |
|EPB (J/bit) | 300f | 33p | 12p | 8.5p | 17.5p | 890f|
|FCC compliant | - | Yes | Yes | Yes | Yes | Yes |

# Refernces:

[^1]: A.Chandrakasan, F.Lee, D.Wentzloff, V.Sze, B.Ginsburg, P.Mercier,  D.Daly, and R.Blazquez, ''Low-power impulse uwb architectures and  circuits,'' Proc. IEEE, vol.97, no.2, pp. 332 --352, 2009.
[^2]: A.Eftekhar, S.Paraskevopoulou, and T.Constandinou, ''Towards a next  generation neural interface: Optimizing power, bandwidth and data quality,''  in Proc. IEEE BioCAS, 2010, pp. 122 --125.
[^3]: I.Stevenson and K.Kording, ''How advances in neural recording affect data  analysis,'' Nature neuroscience, vol.14, no.2, pp. 139--142, 2011.
[^4]: T.Buchegger, G.Ossberger, A.Reisenzahn, A.Stelzer, and A.Springer, ''Pulse  delay techniques for ppm impulse radio transmitters,'' in Proc. IEEE  Conf. UWB Syst. Tech., 2003, pp. 37 -- 41.
[^5]: R.Hoctor and H.Tomlinson, ''Delay-hopped transmitted-reference rf  communications,'' in Proc. IEEE Conf. UWB Syst. Tech., 2002, pp.  265--269.
[^6]: L.Moreira, W.van Noije, D.Silveira, S.Kofuji, and C.Sassaki, ''A small  area 2.8pj/pulse 7th derivative gaussian pulse generator for ir-uwb,'' in  Proc. CJMW, 2011, pp. 1 --4.
[^7]: J.Liang, C.Chiau, X.Chen, and C.Parini, ''Study of a printed circular disc  monopole antenna for uwb systems,'' IEEE Trans. Antennas and  Propagation, vol.53, no.11, pp. 3500 -- 3504, 2005.
[^8]: M.Mark, Y.Chen, C.Sutardja, C.Tang, S.Gowda, M.Wagner, D.Werthimer, and  J.Rabaey, ''A 1mm$^3$ 2mbps 330fj/b transponder for implanted neural  sensors,'' in Proc. IEEE VLSIC, 2011, pp. 168--169.
[^9]: B.Qin, H.Chen, X.Wang, A.Wang, Y.Hao, L.Yang, and B.Zhao, ''A  single-chip 33pj/pulse 5th-derivative gaussian based ir-uwb transmitter in  0.13$\mu$m cmos,'' in Proc. IEEE ISCAS, 2009, pp. 401--404.
[^10]: Y.Park and D.Wentzloff, ''An all-digital 12pj/pulse 3.1 - 6.0ghz ir-uwb  transmitter in 65nm cmos,'' in Proc. IEEE ICUWB, vol.1, 2010, pp.  1--4.
[^11]: H.Miranda and T.Meng, ''A programmable pulse uwb transmitter with 34% energy  efficiency for multichannel neuro-recording systems,'' in Proc. IEEE  CICC, 2010, pp. 1--4.
[^12]: P.Mercier, D.Daly, and A.Chandrakasan, ''An energy-efficient all-digital uwb  transmitter employing dual capacitively-coupled pulse-shaping drivers,''  IEEE JSSC, vol.44, no.6, pp. 1679--1688, 2009.
